<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>uusi</translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Ei koskaan</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Joka vuorolla</numerusform>
            <numerusform>Joka %1:s vuoro</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Muokkaa aseita</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Virheellinen ammussuunnitelma</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Muokkaa kaavaa</translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation>%1 *** %2 on poistanut sinut huomiotta jättö-listaltaan</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation>%1 *** %2 on lisännyt sinut huomiotta jättö-listalleen</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation>%1 *** %2 on poistanut sinut kaverilistaltaan</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation>%1 *** %2 on lisännyt sinut kaverilistalleen</translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>new</source>
        <translation>uusi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Palvelimen käynnistys ei onnistunut</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Nauhoitetta ei voitu tallentaa tiedostoon %1</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Ole hyvä ja valitse nauhoite ylläolevasta listasta</translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>fi.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Demotiedostoa %1 ei pystytty avaamaan</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Kartta</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Suodatin</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pieni</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Keskikokoinen</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Suuri</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Kaivos</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Sekopäinen</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Teemat</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Tyyppi</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Palvelinta ei löydetty. Ole hyvä ja tarkista palvelimen nimi ja porttiasetukset.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Yhteys hylätty</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Huone tuhottiin</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Poistumisssyy: </translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Sinut potkittiin</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation>Nimimerkkisi %1 on
rekisteröity Hedgewars.org:ssa
Ole hyvä ja syötä salasana
tai valitse toinen nimimerkki:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 liittyi huoneeseen</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 liittyi</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 poistui</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 poistui (%3)</translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf palautti virheen mallintaessaan tekstiä, todennäköisesti syy on freetype2:n ohjelmavirheessä. Freetype-kirjaston päivitys on suosiltetavaa.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Palvelimen viesti:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Aseta viesti</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Tyhjennä käyttäjätili-välimuisti</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set data</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Yhdistetään...</translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Lisäasetukset</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Paras laukaus -mitalin voitti &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt; pisteellä&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Paras tappaja oli &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;yhdellä&lt;/b&gt; tapolla vuoron aikana&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Paras tappaja oli &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt;:llä tapolla &lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation>
            <numerusform>&lt;p&gt;Yhteensä &lt;b&gt;yksi&lt;/b&gt; siili tapettiin tällä kierroksella.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Yhteensä &lt;b&gt;%1&lt;/b&gt; siiltä tapettiin tällä kierroksella.&lt;/p&gt;</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Paikallinen peli (Pelaa yhdellä tietokoneella)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Verkkopeli (Pelaa verkon yli)</translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Ole hyvä ja valitse palvelin ylläolevasta listasta</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Säädöt</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Lähiverkkopeli</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Virallinen palvelin</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Uusi joukkue</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Muokkaa joukkuetta</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Uudelleennimeämis-dialogi</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Syötä uusi tiedostonimi:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Ei voida uudelleennimetä</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Ei voida poistaa tiedostoa</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Ole hyvä ja valitse nauhoite listasta</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Luo</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Liity</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Ylläpitäjän ominaisuudet</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Huoneen nimi:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Tämä peli on eteisessä.
Voit liittyä ja alkaa pelaamaan sitten kun peli alkaa.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Tämä peli on menossa.
Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä päästäksesi pelaamaan.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 on isäntä. Hän voi säätää asetuksia ja aloittaa pelin.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Satunnainen kartta</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Pelejä voi pelata valmiiksi luoduissa tai satunnaisesti tehdyissä kartoissa.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Pelikaava määrittelee yleiset asetukset ja säädöt kuten kierrosajan, äkkikuoleman ja vampyrismin.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Asesuunnitelma määrittelee saatavilla olevat aseet ja niiden panosmäärät.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Yksi asiakas on liittyneenä tähän huoneeseen</numerusform>
            <numerusform>%1 asiakasta on liittyneenä tähän huoneeseen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Tässä huoneessa on osallistuneena yksi joukkue</numerusform>
            <numerusform>Tässä huoneessa on osallistuneena %1 joukkuetta</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Ole hyvä ja syötä huoneen nimi</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Ole hyvä ja valitse huone listalta</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Puolusta linnaasi ja tuhoa vastustajasi, maksimissaan kaksi joukkueväriä!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Joukkueet aloittavat kartan vastakkaisista päistä, maksimissaan kaksi joukkueväriä!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Maata ei voi tuhota!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation>Lisää tuhoutumattomat reunat kartan ympärille</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Matalampi painovoima</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Lasertähtäimellä avustettu tähtäys</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Kaikilla siileillä on oma suojakenttänsä</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation>Lisää miinoja satunnaisesti</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Saa 80% aiheuttamastasi vahingosta takaisin omaan terveyteesi</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Jaa vastuastajasi tuska, jaa heidän vahinkonsa</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Kaikki siilit ovat liikkumattomia, testaa tykistötaitojasi</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Satunnainen</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekuntia</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Pelaamisjärjestys on satunnainen huoneen järjestyksen sijaan.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Pelaa kuninkaalla. Jos hän kuolee, sinun jokkueesi häviää.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Sijoittakaa siilenne vuorotellen ennen pelin alkua.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Ammukset ovat yhteiset saman värin kesken.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Kytke palkit pois päältä satunnaisissa kartoissa.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Yksinkertainen peli (pikapeli tietokonetta vastaan, asetukset valitaan puolestasi)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Moninpeli (pelaa samalla koneella kavereitasi tai tekoälyä vastaan)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation>Harjoittelu (Harjoita taitojasi harjoitustasoissa). KEHITYKSEN ALLA</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demot (Katso nauhoitettuja demoja)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Lataa (Lataa aikaisemmin tallennettu peli)</translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Potki</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Rajoita liittymisiä</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Rajoita joukkuelisäyksiä</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Anna porttikielto</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Seuraa</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Jätä huomiotta</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Lisää kaveriksi</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Ota huomion</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Poista kaverilistalta</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Tarkista päivitykset käynnistyksessä</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko ruutu</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Koko ruutu käyttöliittymälle</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Äänet päälle</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Musiikki päälle</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Näytä FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Vaihtoehtoinen vahingon näyttäminen</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Lisää päivämäärä ja aika nauhoitusten tiedostonimeen</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation>Huononnettu laatu</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Näytä asevalikon vihjeet</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Kytke käyttöliittymän äänet päälle</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Kytke käyttöliittymän musiikki päälle</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Käyttöliittymän tehosteet</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>generoitu kartta...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Ihminen</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Taso</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Järjestelmän oletus)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mission</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Joukkueen jäsenet</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Linnake</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Näppäinasettelut</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Joukkueet</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Aseet</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Verkkopeli</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Pelaavat joukkueet</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Ääni/grafiikka-asetukset</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Pelimuuttujat</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Perusasetukset</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Joukkueasetukset</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Muut</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Miinojen aika</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Miinat</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation>Tätä ohjelmaa levitetään GNU General Public Licence-lisensisn alla</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Kehittäjät:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Taide:</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Äänet:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Käännökset:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Erikoiskiitokset:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Aseet</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Palvelin:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Portti:</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Verkkopeli-nimimerkki</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resoluutio</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS-raja</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Palvelimen nimi:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Palvelimen portti:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Alkuperäinen äänten voimakkuus</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Vahinkomuuttuja</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Vuoron aika</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Aloitusterveys</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Äkkikuoleman ajastus</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Kaavan nimi:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Laatikkojen pudotukset</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Pelikaava</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% suutarimiinoja</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Hauta</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Lippu</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Ääni</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Kieli</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Käynnistä peli uudelleen ottaaksesi muutokset käyttöön</translation>
    </message>
    <message>
        <source>This SVN build is &apos;work in progress&apos; and may not be compatible with other versions of the game.
Some features might be broken or incomplete. Use at your own risk!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>nimetön</translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Yhteys palvelimeen katosi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Data-hakemiston avaus epäonnistui:
 %1
Ole hyvä ja tarkista asennuksesi</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Aseet</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation>Oletus-asesettiä ei voi muokata</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation>Oletus-asesettiä ei voi poistaa</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Haluatko todella poistaa tämän asesetin?</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Hakemiston %1 luonti epäonnistui</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nimimerkki</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Ole hyvä ja syötä nimimerkkisi</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>default</source>
        <translation>oletus</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Käynnistä palvelin</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Määritä</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Aloita!</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Toista nauhoite</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Satunnainen joukkue</translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Huoneen nimi</translation>
    </message>
    <message>
        <source>C</source>
        <translation>A</translation>
    </message>
    <message>
        <source>T</source>
        <translation>J</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Omistaja</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Kartta</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Säännöt</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Aseet</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Asesetti</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Todennäköisyydet</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Ammukset laatikoissa</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Viipeet</translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Palvelinta ei pystytty käynnistämään: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Pelimoottorin ajo epäonnistui: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampyrismi</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Tykistö</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Linnoitustila</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Jaa joukkueet</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Tuhoutumaton maa</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Lisää reunat</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Matala painovoima</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Lasertähtäin</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Vahingoittumaton</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation>Lisää miinat</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Satunnainen Järjestys</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Kuningas</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Sijoita siilet</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Saman väriset jakavat ammukset</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Ei palkkeja</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>ylös</translation>
    </message>
    <message>
        <source>left</source>
        <translation>vasen</translation>
    </message>
    <message>
        <source>right</source>
        <translation>oikea</translation>
    </message>
    <message>
        <source>down</source>
        <translation>alas</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>hyökkäys</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>tarkka tähtäys</translation>
    </message>
    <message>
        <source>put</source>
        <translation>laita</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>vaihto</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>etsi siili</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>asevalikko</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>Paikka 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>Paikka 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>Paikka 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>Paikka 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>Paikka 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>Paikka 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>Paikka 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>Paikka 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>Paikka 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>ajasta 1 sek</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>ajasta 2 sek</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>ajasta 3 sek</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>ajasta 4 sek</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>ajasta 5 sek</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>keskustelu</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>keskusteluhistoria</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>tauko</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>varmistus</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>vähennä äänenvoimakkutta</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>lisää äänenvoimakkutta</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>vaihda tilaa</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>kaappaa</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>siilien
tiedot</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>poistu</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>lähennä</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>loitonna</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>nollaa zoom</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>pitkä hyppy</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>korkea hyppy</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Peruskontrollit</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Asekontrollit</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Kameran ja kursorin kontrollit</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Liikuta siiliäsi ja tähtää:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Ylitä aukot ja esteet hyyppäämällä:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Ammu valitulla aseella tai käytä apuvälinettä:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Valitse ase tai kohde kursorilla:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Vaihda aktiivinen siili (jos mahdollista):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Valitse ase tai apuväline:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Ajasta pommi ja ajastetut aseet:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Liikuta kamera aktiivisen siilen luokse:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Liikuta kursoria tai kameraa ilman hiirtä:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Muuta kameran zoomausta:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Puhu joukkueellesi tai kaikille osanottajille:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Tauota, jatka tai poistu pelistä:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Vaihda pelin äänenvoimakkuutta pelin aikana:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Vaihda kokonäyttö-tilaan/tilasta:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Ota kuvankaappaus:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Vaihda siilien yläpuolella näkyviä &quot;leimoja&quot;:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Akselit</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Ylös)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Alas)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Hattu</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Vasen)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Oikea)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Nappi</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Näppäimistö</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Hiiri: Keskinappi</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Hiiri: Oikea nappi</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Hiiri: Rulla ylös</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Hiiri: Rulla alas</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Askelapalutin</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Sarkain</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Rivinvaihto</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tauko</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Esc-näppäin</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Välilyönti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poistonäppäin</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Rivinvaihto</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>=</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Lisää-nappi</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home-nappi</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End-nappi</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Sivu ylös</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Sivu alas</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Oikea vaihtonäppäin</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Vasen vaihtonäppäin</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Oikea ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Vasen ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Oikea alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Vasen alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Oikea meta</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Vasen meta</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>A-painike</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>B-painike</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>X-painike</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Y-painike</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>LB-painike</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>RB-painike</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Paluu-painike</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Start-painike</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Vasen tikku</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Oikea tikku</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Vasen tikku (Oikea)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Vasen tikku (Vasen)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Vasen tikku (Alas)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Vasen tikku (ylös)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Vasen liipasin</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Oikea liipasin</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Oikea tikku (Alas)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Oikea tikku (Ylös)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Oikea tikku (Oikea)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Oikea tikku (Vasen)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
